@@ -8,7 +8,8 @@ import logging
 from typing import Dict
 
 from aliyunsdkecs.request.v20140526 import DescribeInstancesRequest, DescribeInstanceAttributeRequest, DescribeDisksRequest, \
-    DescribeInstanceTypesRequest, AllocatePublicIpAddressRequest, StartInstanceRequest, DescribeVpcsRequest, AddTagsRequest, JoinSecurityGroupRequest,StopInstanceRequest,ModifyInstanceSpecRequest,ModifyPrepayInstanceSpecRequest
+    DescribeInstanceTypesRequest, AllocatePublicIpAddressRequest, StartInstanceRequest, DescribeVpcsRequest, AddTagsRequest, JoinSecurityGroupRequest, \
+    StopInstanceRequest, ModifyInstanceSpecRequest, ModifyPrepayInstanceSpecRequest
 
 from aliyunsdkrds.request.v20140815 import DescribeDBInstancesRequest, DescribeDBInstanceAttributeRequest, DescribeResourceUsageRequest, \
     DescribeBackupsRequest, CreateBackupRequest, DescribeBackupTasksRequest, CreateDBInstanceRequest, ModifySecurityIpsRequest
@@ -48,7 +49,6 @@ class Base:
             except Exception as e:
                 print(f"未知錯誤 請求重試 {e}")
 
-
         if not status:
             logger.error('多次請求錯誤')
             raise Exception('多次請求錯誤')
@@ -62,8 +62,6 @@ class Base:
         return pagenum
 
 
-
-
 class ECS(Base):
     totalstring = 'TotalCount'
 
@@ -127,7 +125,7 @@ class ECS(Base):
         """取得公網iP
 
         :param id:
-        :return:  {'RequestId': '1FBBB5EF-076C-4CB7-AC61-1F2E04311317', 'IpAddress': '47.91.154.171'}
+        :return:
         """
         request = AllocatePublicIpAddressRequest.AllocatePublicIpAddressRequest()
         request.set_InstanceId(id)
@@ -139,7 +137,7 @@ class ECS(Base):
         '''啟動實例
 
         :param id:
-        :return: {'RequestId': '9AE22337-A958-4B62-8A10-759981BE598E'}
+        :return:
         '''
         request = StartInstanceRequest.StartInstanceRequest()
         request.set_InstanceId(id)
@@ -166,14 +164,14 @@ class ECS(Base):
         response = self.do_action(request)
         return response
 
-    def addSecurityGroup(self,id,securitygroupid):
+    def addSecurityGroup(self, id, securitygroupid):
         request = JoinSecurityGroupRequest.JoinSecurityGroupRequest()
         request.set_InstanceId(id)
         request.set_SecurityGroupId(securitygroupid)
         response = self.do_action(request)
         return response
 
-    def updateModifyInstance(self,id,instancetype):
+    def updateModifyInstance(self, id, instancetype):
         """调用ModifyInstanceSpec调整一台按量付费ECS实例的实例规格和公网带宽大小。
 
         :param id:
@@ -186,7 +184,7 @@ class ECS(Base):
         response = self.do_action(request)
         return response
 
-    def updateModifyPrepayInstance(self,id,instancetype):
+    def updateModifyPrepayInstance(self, id, instancetype):
         """调用ModifyPrepayInstanceSpec升级或者降低一台包年包月ECS实例的实例规格，新实例规格将会覆盖实例的整个生命周期。
 
         :param id:
@@ -199,13 +197,20 @@ class ECS(Base):
         response = self.do_action(request)
         return response
 
-    def stopInstance(self,id):
+    def stopInstance(self, id):
         request = StopInstanceRequest.StopInstanceRequest()
         request.set_InstanceId(id)
         response = self.do_action(request)
         return response
 
-
+    def get_mapping_site_ip(self):
+        data = {}
+        for i in self.ins_list:
+            data[i['InstanceName']] = {
+                'PrivateIpAddress': i['VpcAttributes']['PrivateIpAddress']['IpAddress'],
+                'PublicIpAddress': i['PublicIpAddress']['IpAddress']
+            }
+        return data
 
 
 class RDS(Base):
@@ -267,6 +272,7 @@ class RDS(Base):
         :return:
         '''
         ids = [i['DBInstanceId'] for i in self.ins_list if i['DBInstanceDescription'] == name]
+        print(ids)
         if ids:
             return ids[0]
         else:
@@ -288,7 +294,7 @@ class RDS(Base):
         ret = self.do_action(request)
         backup_list = []
         for lst in ret['Items']['Backup']:
-            lst['datetime'] = datetime.datetime.strptime(lst['BackupEndTime'], '%Y-%m-%dT%H:%M:%S%z')
+            lst['Datetime'] = datetime.datetime.strptime(lst['BackupEndTime'], '%Y-%m-%dT%H:%M:%S%z')
             backup_list.append(lst)
 
         return backup_list
@@ -298,50 +304,29 @@ class RDS(Base):
 
         :param name:
         :param id:
-        :return: {
-         'BackupDBNames': 'cp33dg,dscp,passport,sys,try_dscp',
-         'BackupDownloadURL': 'https://rdsbak-hk45-v2.oss-cn-hongkong.aliyuncs.com/custins5875919/hins6483427_data_20201007175114.tar.gz?Expires=1602322500&OSSAccessKeyId=STS.NSkBp4bYuaUaKcV5TxCXUi7vz&Signature=%2FaPxJ9dLRR90JktAU%2FxVGNv3mlg%3D&security-token=CAISrgJ1q6Ft5B2yfSjIr5DeCcqAj4ZU1peKSUXn0VQtT9d5hvLdmDz2IHpNfXZuAuEctvo%2BnGtR5%2F8clqBZQpRGWFTtdcooH3LrKrnnMeT7oMWQweEuYPTHcDHhGHyW9cvWZPqDA7G5U%2FyxalfCuzZuyL%2FhD1uLVECkNpv77vwCac8MDCa1cR1MBtpdOnFDyqkgOGDWKOymPzPzn2PUFzAIgAdnjn5l4qnNh6%2Ff4xHF3lrh0b1X9cajOJS%2FZcBveZd8D4rwwrYxfbfazC9W8EUaq%2Fon1f0DuxW%2F54HBXgIBskzdYrOIr40%2BczUUPPZqR%2FR2y9HnjuB9t%2BDpkID69g1AJ%2Bk9UV6EHtn5n5WfSbnxaIdhLu%2BqYirXtcuTLdzvrEYjemleLgROdsrgq%2Ba4k7%2FnIRqAAVOQ2CL59nXexxKqqrtyrHsFGg3Cgmx2AiENLN1lfNXa8BPEghwmVg0f2ue2fNZsFHZwtFzhtfopzGaKbKI%2FOCxWCnum3giAuzG2PR9orXMOGH5nHDTvgqsoKCxtJA2DcOo%2BySkLPePRkGZMl7Dxv%2FK%2BlGWB4TX7u65yoNbwLcZD',
-         'BackupEndTime': '2020-10-08T02:11:08Z',
-         'BackupId': 756129409,
-         'BackupInitiator': 'User',
-         'BackupIntranetDownloadURL': 'http://rdsbak-hk45-v2.oss-cn-hongkong-internal.aliyuncs.com/custins5875919/hins6483427_data_20201007175114.tar.gz?Expires=1602322500&OSSAccessKeyId=STS.NSkBp4bYuaUaKcV5TxCXUi7vz&Signature=%2FaPxJ9dLRR90JktAU%2FxVGNv3mlg%3D&security-token=CAISrgJ1q6Ft5B2yfSjIr5DeCcqAj4ZU1peKSUXn0VQtT9d5hvLdmDz2IHpNfXZuAuEctvo%2BnGtR5%2F8clqBZQpRGWFTtdcooH3LrKrnnMeT7oMWQweEuYPTHcDHhGHyW9cvWZPqDA7G5U%2FyxalfCuzZuyL%2FhD1uLVECkNpv77vwCac8MDCa1cR1MBtpdOnFDyqkgOGDWKOymPzPzn2PUFzAIgAdnjn5l4qnNh6%2Ff4xHF3lrh0b1X9cajOJS%2FZcBveZd8D4rwwrYxfbfazC9W8EUaq%2Fon1f0DuxW%2F54HBXgIBskzdYrOIr40%2BczUUPPZqR%2FR2y9HnjuB9t%2BDpkID69g1AJ%2Bk9UV6EHtn5n5WfSbnxaIdhLu%2BqYirXtcuTLdzvrEYjemleLgROdsrgq%2Ba4k7%2FnIRqAAVOQ2CL59nXexxKqqrtyrHsFGg3Cgmx2AiENLN1lfNXa8BPEghwmVg0f2ue2fNZsFHZwtFzhtfopzGaKbKI%2FOCxWCnum3giAuzG2PR9orXMOGH5nHDTvgqsoKCxtJA2DcOo%2BySkLPePRkGZMl7Dxv%2FK%2BlGWB4TX7u65yoNbwLcZD',
-         'BackupLocation': 'OSS',
-         'BackupMethod': 'Physical',
-         'BackupMode': 'Manual',
-         'BackupScale': 'DBInstance',
-         'BackupSize': 279236241408,
-         'BackupStartTime': '2020-10-07T09:52:03Z',
-         'BackupStatus': 'Success',
-         'BackupType': 'FullBackup',
-         'ConsistentTime': '1602122536',
-         'DBInstanceId': 'rm-3ns9baf5udb842328',
-         'HostInstanceID': 6483427,
-         'IsAvail': 1,
-         'MetaStatus': '',
-         'SlaveStatus': '{"GTID_PURGED": '
-                        '"0424749e-c668-11e8-b9f5-506b4b436954:1-174226402, '
-                        '"BINLOG_FILE": "mysql-bin.008838", "BACKUP_TIME": "total '
-                        '58210, innodb_data 58210, FTWRL_lock 0, table_checksum 0, '
-                        'tokudb_data 0, innodb_log 58210, tokudb_log 0, '
-                        'consistent_time 1602122536", "MASTER_HOSTINS_ID": 6168815, '
-                        '"SLAVE_HINSID": "6168815", "BINLOG_HINSID": 6483427, '
-                        '"SLAVE_POS": "161110786", "BACKUP_HOSTINS_ROLE": "slave", '
-                        '"BINLOG_POS": "404324363", "SLAVE_FILE": "mysql-bin.009289", '
-                        '"ConsistentTime": 1602122536}',
-         'StorageClass': '0',
-         'StoreStatus': 'Disabled',
-         'datetime': datetime.datetime(2020, 10, 8, 2, 11, 8, tzinfo=datetime.timezone.utc)}
+        :return:
         '''
         backup_list = self.getBackupList(name=name, id=id)
-        d = max([i['datetime'] for i in backup_list])
-        return [i for i in backup_list if i['datetime'] == d][0]
+        d = max([i['Datetime'] for i in backup_list])
+        _data = [i for i in backup_list if i['Datetime'] == d][0]
+        data = {
+            'Name': name,
+            'DBInstanceId': _data['DBInstanceId'],
+            'BackupIntranetDownloadURL': _data['BackupIntranetDownloadURL'],
+            'BackupDownloadURL': _data['BackupDownloadURL'],
+            'BackupEndTime': datetime.datetime.fromtimestamp(_data['Datetime'].timestamp()).strftime("%Y/%m/%d %H:%M:%S"),
+            'BackupSize': f"{int(_data['BackupSize'] / 1024 / 1024 // 1024)}G",
+            'FileName': _data['BackupIntranetDownloadURL'].split('/')[-1].split('?Expires')[0]
+
+        }
+        return data
 
     def createBackup(self, name=None, id=None) -> dict:
         '''創建備份任務
 
         :param name:
         :param id:
-        :return: {'RequestId': 'CC0CCB8A-0BBA-4A36-9EDD-3BE44B0F97BB', 'BackupJobId': '11291454'}
+        :return:
         '''
         if name:
             id = self.getDBInstanceID(name)
@@ -356,41 +341,13 @@ class RDS(Base):
 
         :param id:
         :param jobid:
-        :return: {
-            'BackupJobId': 11291454,
-            'BackupProgressStatus': 'Preparing',
-            'BackupStatus': 'Preparing',
-            'JobMode': 'Manual',
-            'Process': '25',
-            'TaskAction': 'TempBackupTask'
-        }
-
+        :return:
         '''
         request = DescribeBackupTasksRequest.DescribeBackupTasksRequest()
         request.set_DBInstanceId(id)
         request.set_BackupJobId(jobid)
         ret = self.do_action(request)
-        '''
-         {
-            'Items': {'BackupJob': [{'BackupJobId': 11291454,
-                          'BackupProgressStatus': 'Preparing',
-                          'BackupStatus': 'Preparing',
-                          'JobMode': 'Manual',
-                          'Process': '25',
-                          'TaskAction': 'TempBackupTask'}]},
-            'RequestId': '7E18CB32-BE5D-478F-9D11-3EF885095B4E'
-        }
-        完成
-        {'Items': {'BackupJob': [{'BackupId': '756129409',
-                          'BackupJobId': 11291454,
-                          'BackupProgressStatus': 'Finished',
-                          'BackupStatus': 'Finished',
-                          'JobMode': 'Manual',
-                          'Process': '125',
-                          'TaskAction': 'TempBackupTask'}]},
-         'RequestId': 'FCB1A6A2-6B1B-46D1-90E5-FF1C07C73499'}
-        '''
-        # print(ret)
+
         return ret['Items']['BackupJob'][0] if ret['Items']['BackupJob'] else {}
 
     def createInstance(self, name, type, version, storage, paytype, dbclass, security_ip_list='127.0.0.1', vpcid=None):
